@@ -21,14 +21,18 @@ class Keyboard( QtDeclarative.QDeclarativeView ) :
         if ( not parent ) and daemonFlag :
             self.setWindowFlags( QtCore.Qt.Dialog | QtCore.Qt.FramelessWindowHint )
             self.daemonFlag = daemonFlag
-        self.setAttribute( QtCore.Qt.WA_Maemo5PortraitOrientation, False )
+        #self.setAttribute( QtCore.Qt.WA_Maemo5PortraitOrientation, False )
 
         self.setAttribute( QtCore.Qt.WA_TranslucentBackground, True )
         palette = QtGui.QPalette()
         palette.setColor( QtGui.QPalette.Base, QtCore.Qt.transparent )
         self.setPalette( palette )
 
+        #self.keepedWidth = 800
+        #self.keepedHeight = 480
+
         self.mouseTracker = Tracker()
+        self.sceneResized.connect( self.keepSize )
     def set( self, qmlSourcePath, engine = None, engineName = "" ) :
         self.setSource( QtCore.QUrl( qmlSourcePath ) ) ;
         if engine :
@@ -42,7 +46,20 @@ class Keyboard( QtDeclarative.QDeclarativeView ) :
         root = self.rootObject()
         self.setText = root.setText
         self.getText = root.getText
-        root.close.connect( self.close )
+        self.keepedWidth = root.width()
+        self.keepedHeight = root.height()
+        self.rotateSignal = root.rotateSignal
+        #root.close.connect( self.close )
+    @QtCore.Slot( QtCore.QSize)
+    def keepSize( self, size ) :
+        #print "keep"
+        if ( self.daemonFlag ) :
+            width = self.size().width()
+            height = self.size().height()
+            #print width, height, self.keepedWidth, self.keepedHeight
+            if height != self.keepedHeight or width != self.keepedWidth :
+                #print width, height, self.keepedWidth, self.keepedHeight
+                self.resize( self.keepedWidth, self.keepedHeight )
     def closeEvent( self, event ) :
         if self.daemonFlag :
             self.hide()
@@ -53,6 +70,8 @@ class Keyboard( QtDeclarative.QDeclarativeView ) :
 
 
 if __name__ == "__main__" :
+    def r() :
+        print "r"
     import config
     import sys
     from engine import IMEngine
@@ -61,6 +80,8 @@ if __name__ == "__main__" :
     view = Keyboard()
     engine = IMEngine()
     view.set( "./qml/qwert.qml", engine )
+    #view.setAttribute( QtCore.Qt.WA_Maemo5PortraitOrientation, True )
+    view.rotateSignal.connect( r )
 
     path = config.check_path( config.sysdict_path )
     print "load sysdict from :", path
